import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['#f56042', '#ffb53d']);

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([50, 30]);


export const fruitsBowl = (selection, props) => {
	const { 
    fruits, 
    height, 
    width, 
    onClick, 
    selectedFruit 
  } = props;
  
  const xPosition = (d, i) => i * 120 + width / 2 - 150;
  const circles = selection.selectAll('circle')
  .data(fruits, d => d.id);
  	
  circles.enter().append('circle')
    .attr('cy', height / 2)
  	.attr('r', 0)
  	.attr('cx', xPosition)
    .merge(circles)
    .attr('fill', d => colorScale(d.type))
  	.attr('stroke', d => 
          d.id === selectedFruit
          ? 'black'
          : 'none')
  	.attr('stroke-width', '5px')
  	.on('click', d => onClick(d.id))
    .transition().duration(1000)
  	.attr('cx', xPosition)
    .attr('r', d => radiusScale(d.type));

	circles.exit()
    .transition().duration(1000)
  	.attr('r', 0)
    .remove();
}

